#!/usr/bin/perl 
use strict;
use warnings;
use Net::SNMP;

#oid of the mailstat exec extension in snmp agent
my $mailstat = '.1.3.6.1.4.1.2021.8.1.101.1';

my $hostname	=  $ARGV[0] if defined $ARGV[0];
my $port	=  $ARGV[1] if defined $ARGV[1];
my $version	=  $ARGV[2] if defined $ARGV[2];
my $auth_info   = $ARGV[3] if defined $ARGV[3];

if(!defined $auth_info || $auth_info !~ /:/){
	print "Invalid argument\n";
	exit(1);
}

my ($community, $username, $password, $auth_proto, $priv_passwd, $priv_proto) = split /:/, $auth_info;


# get information via SNMP
# create session object
my %opt = (
	-hostname      => $hostname,
	-port          => $port,
	-version       => $version, 
	);

if($version ne 3){
	%opt = (
		%opt,
		-community => $community,
		);
}else{
	%opt = (
		%opt,
		-username      => $username,
		-authpassword  => $password,
		-authprotocol  => $auth_proto,
		);
	if(defined($priv_passwd) && $priv_passwd){
		%opt = (
			%opt,
			-privpassword => $priv_passwd,
            -privprotocol  => $priv_proto,
			);
	}
}

my ($session, $error) = Net::SNMP->session(%opt);
# on error: exit
if (!defined($session)) {
        printf("ERROR: %s.\n", $error);
        exit 1;
        }
# 
my $result = $session->get_request(
                         -varbindlist      => [$mailstat]
	);

# on error: exit
if (!defined($result)) {
        printf("ERROR2: %s.\n", $session->error);
        $session->close;
        exit 1;
        }

print "$result->{$mailstat}\n";
